@@ -156,7 +156,7 @@ def LoadRecord():
     print "Open Log file:",  data.logfolder+data.logfilename,  "to load data..."
     if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
         os.mkdir(data.logfolder)
-        data.lastlogfile=""
+        data.LastRecord=""
     f=data.logfolder+data.logfilename
     if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist
 
@@ -345,4 +345,3 @@ def UpdateFileHeader():
         file.write(d+"\n")
     file.close()
     if(data.debug==1): print "Wrote",  i +1,  "records into file"
-
