@@ -11,6 +11,7 @@ import ConfigParser
 import os, os.path
 
 import data
+import filter_data #filter
 import records #record data
 
 #own functions
@@ -131,21 +132,18 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 
 
 def FilterData():
-        Xscale=data.arrXscale[data.Xscale]
-
-        arrSend=[0]*(records.Index+len(data.arrFilter))
-        for i in range(0,  records.Index-data.Derivation): #copy array
-            arrSend[i]=records.arrData[4][i]
-
-        arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, data.arrFilter, data.FilterShift, 61-data.filterScale)
-#        print arrRet
-        for i in range(0,  records.Index-data.Derivation): #copy array and scale
-            records.arrData[6][i]  = arrRet[i]
-            if(records.arrData[6][i] > data.Ysize-7):
-                records.arrData[6][i]  = data.Ysize-7 #-int(random.uniform(1, 2))
-            elif(records.arrData[6][i] < 13): records.arrData[6][i] =13
+    #NOTE:
+    #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
+    #So we have to copy out this part and readd it later on:
+    arrSend=[0]*(records.Index+len(filter_data.arrFilter))
+    for i in range(0,  records.Index-data.Derivation): #copy array
+        arrSend[i]=records.arrData[4][i]
 
+    #Exported function:
+    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, 61-data.FilterScale, data.Ysize-7, 13)
 
+    for i in range(0,  records.Index-data.Derivation): #copy array and scale
+        records.arrData[6][i]  = arrRet[i]
 
 
 
@@ -812,7 +810,4 @@ def PrintRecordData(ShowArray=True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i]
 
-    print "##########################################################"
-
-
-
+    print "##########################################################"
\ No newline at end of file
